/***************************************************************************
* Copyright (c) 2013 Abdurrahman AVCI <abdurrahmanavci@gmail.com>
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the
* Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
***************************************************************************/

#ifndef DDM_CONSTANTS_H
#define DDM_CONSTANTS_H

#define BIN_INSTALL_DIR             "/usr/bin"
#define LIBEXEC_INSTALL_DIR         "/usr/lib"
#define DATA_INSTALL_DIR            "/usr/share/ddm"
#define SYS_CONFIG_DIR              "/etc"
#define COMPONENTS_TRANSLATION_DIR  "/usr/share/ddm/translations"
#define RUNTIME_DIR                 "/run/ddm"
#define STATE_DIR                   "/var/lib/ddm"
#define ACCOUNTSSERVICE_DATA_DIR    "/var/lib/AccountsService"

#define SESSION_COMMAND             "/usr/share/ddm/scripts/Xsession"
#define WAYLAND_SESSION_COMMAND     "/usr/share/ddm/scripts/wayland-session"

#define CONFIG_FILE                 "/etc/ddm.conf"
#define CONFIG_DIR                  "/etc/ddm.conf.d"
#define SYSTEM_CONFIG_DIR           "/usr/lib/ddm/ddm.conf.d"

#define LOG_FILE                    "/var/log/ddm.log"

#define UID_MIN                     1000
#define UID_MAX                     60000

#define HALT_COMMAND "/usr/bin/systemctl poweroff"
#define REBOOT_COMMAND "/usr/bin/systemctl reboot"

#endif // DDM_CONSTANTS_H
